/* gtkentryextra.h - GtkEntry widget with autocompletion
 *
 * Authors:           Tim Janik   
 *                    Kristian Rietveld <kristian@planet.nl>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GTK_ENTRY_EXTRA_H__
#define __GTK_ENTRY_EXTRA_H__

#include <gtk/gtkentry.h>
#include "gtkcomboboxtext.h"

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_ENTRY_EXTRA            (gtk_entry_extra_get_type ())
#define GTK_ENTRY_EXTRA(object)         (GTK_CHECK_CAST ((object), GTK_TYPE_ENTRY_EXTRA, GtkEntryExtra))
#define GTK_ENTRY_EXTRA_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), GTK_TYPE_ENTRY_EXTRA))
#define GTK_IS_ENTRY_EXTRA(object)      (GTK_CHECK_TYPE ((object), GTK_TYPE_ENTRY_EXTRA))
#define GTK_IS_ENTRY_EXTRA_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), GTK_TYPE_ENTRY_EXTRA))

typedef struct _GtkEntryExtraClass GtkEntryExtraClass;
typedef struct _GtkEntryExtra      GtkEntryExtra;

struct _GtkEntryExtra
{
  /*< public >*/
  GtkEntry         parent_instance;
  
  /*< private >*/
  GtkWidget       *cboxtext; /* ComboBoxText we're related to */
  
  gboolean         autocomplete;
  gboolean         pattern_matching;
  gboolean         keep_history;
  gint             history_length;
};
  
struct _GtkEntryExtraClass
{
  GtkEntryClass parent_class;

  void (*autocompleted) (GtkEntryExtra *entrye,
			 const gchar   *completion);
};

GtkType     gtk_entry_extra_get_type             (void);
GtkWidget  *gtk_entry_extra_new                  (void);

void        gtk_entry_extra_set_keep_history     (GtkEntryExtra *entrye,
						  gboolean       bool);
void        gtk_entry_extra_set_history_length   (GtkEntryExtra *entrye,
						  gint           length);
void        gtk_entry_extra_set_autocomplete     (GtkEntryExtra *entrye,
						  gboolean       bool);
void        gtk_entry_extra_set_pattern_matching (GtkEntryExtra *entrye,
						  gboolean       bool);

/* private */
void gtk_entry_extra_register_combo_box_text     (GtkEntryExtra *entrye,
						  GtkComboBoxText *cboxtext);


#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __GTK_ENTRY_EXTRA_H__ */
